package org.hathitrust.extractedfeatures;

import java.util.Iterator;

import org.json.JSONObject;

public class JSONSolrTransform {

	protected static String generateSolrText(JSONObject ef_token_pos_count)
		{
			StringBuilder sb = new StringBuilder();
	
			Iterator<String> token_iter = ef_token_pos_count.keys();
			while (token_iter.hasNext()) {
				String token = token_iter.next();
			    
				sb.append(token);
				if (token_iter.hasNext()) {
					sb.append(" ");
				}
			}
			
			/*
			Set<String> token_keys = ef_token_pos_count.keySet();
			for (String token : token_keys) {
					sb.append(token + " ");
			}
	*/
			
		   return sb.toString();
		}

	protected static JSONObject generateSolrDocJSON(String volume_id, String page_id, JSONObject ef_page) 
	{
		JSONObject solr_update_json = null;
		
		if (ef_page != null) {
			JSONObject ef_body = ef_page.getJSONObject("body");
			if (ef_body != null) {
				JSONObject ef_token_pos_count = ef_body.getJSONObject("tokenPosCount");
				if (ef_token_pos_count != null) {
	
					JSONObject solr_add_json = new JSONObject();
	
					String text = generateSolrText(ef_token_pos_count);
					
					JSONObject solr_doc_json = new JSONObject();
					solr_doc_json.put("id", page_id);
					solr_doc_json.put("volumeid_s", volume_id);
					solr_doc_json.put("eftext_txt", text);
				   
					solr_add_json.put("commitWithin", 5000);
					solr_add_json.put("doc", solr_doc_json);
					
					solr_update_json = new JSONObject();
					solr_update_json.put("add",solr_add_json);
					
				}
				else {
					System.err.println("Warning: empty tokenPosCount field for '" + page_id + "'");
				}
			}
			else {
				System.err.println("Warning: empty body field for '" + page_id + "'");
			}
			
		}
		else {
			System.err.println("Warning: null page for '" + page_id + "'");
		}
		
		
	    /*
	      
	     /update/json/docs
	     */
	    
		// For Reference ...
		// Example documentation on Solr JSON syntax:
		//   https://cwiki.apache.org/confluence/display/solr/Uploading+Data+with+Index+Handlers
		//     #UploadingDatawithIndexHandlers-JSONFormattedIndexUpdates
		
		/*
		curl -X POST -H 'Content-Type: application/json' 'http://localhost:8983/solr/my_collection/update' --data-binary '
		{
		  "add": {
		    "doc": {
		      "id": "DOC1",
		      "my_boosted_field": {         use a map with boost/value for a boosted field 
		        "boost": 2.3,
		        "value": "test"
		      },
		      "my_multivalued_field": [ "aaa", "bbb" ]    Can use an array for a multi-valued field 
		    }
		  },
		  "add": {
		    "commitWithin": 5000,           commit this document within 5 seconds 
		    "overwrite": false,             don't check for existing documents with the same uniqueKey 
		    "boost": 3.45,                  a document boost 
		    "doc": {
		      "f1": "v1",                   Can use repeated keys for a multi-valued field 
		      "f1": "v2"
		    }
		  },
		 
		  "commit": {},
		  "optimize": { "waitSearcher":false },
		 
		  "delete": { "id":"ID" },          delete by ID 
		  "delete": { "query":"QUERY" }     delete by query 
		}'
		*/
		
		return solr_update_json;
	}

}
